Home
last modified time | relevance | path

Searched refs:stream (Results 1 – 25 of 484) sorted by relevance

12345678910>>...20

/llvm-project-15.0.7/cross-project-tests/debuginfo-tests/dexter/dex/utils/
H A DPrettyOutputBase.py80 if stream is None:
82 return stream
111 stream = self._set_valid_stream(stream)
145 self._stack[-1](before, lock=_null_lock, stream=stream)
151 colors[color](within, lock=_null_lock, stream=stream)
156 self._stack[-1](after, lock=_null_lock, stream=stream)
159 stream = self._set_valid_stream(stream)
164 stream = self._set_valid_stream(stream)
182 fn(line, stream=stream, lock=_null_lock)
185 self.default(line, stream=stream, lock=_null_lock)
[all …]
/llvm-project-15.0.7/cross-project-tests/debuginfo-tests/dexter/dex/utils/windows/
H A DPrettyOutput.py47 if not stream.color_enabled:
51 stream = self._set_valid_stream(stream)
52 self.flush(stream)
53 if stream.orig_color:
55 stream.os, stream.orig_color)
58 stream = self._set_valid_stream(stream)
61 if stream.color_enabled:
63 stream.os, color)
66 if stream.color_enabled:
82 stream = self._set_valid_stream(stream)
[all …]
/llvm-project-15.0.7/libc/utils/UnitTest/
H A DPrintfMatcher.cpp42 stream << form.raw_string[i]; in display()
44 stream << "\""; in display()
46 stream << "\n\tHas Conv\n\tFlags:"; in display()
52 stream << "\n"; in display()
55 stream << "\tlength modifier: "; in display()
67 stream << "\n"; in display()
70 stream << "\tpointer value: " in display()
82 display(stream, expected); in explainError()
83 stream << '\n'; in explainError()
85 display(stream, actual); in explainError()
[all …]
/llvm-project-15.0.7/cross-project-tests/debuginfo-tests/dexter/dex/utils/posix/
H A DPrettyOutput.py13 def _color(self, text, color, stream, lock=_lock): argument
15 stream = self._set_valid_stream(stream)
17 if stream.color_enabled:
19 self._write(text, stream)
21 def red_impl(self, text, stream=None, **kwargs): argument
22 self._color(text, 91, stream, **kwargs)
25 self._color(text, 93, stream, **kwargs)
28 self._color(text, 92, stream, **kwargs)
30 def blue_impl(self, text, stream=None, **kwargs): argument
31 self._color(text, 96, stream, **kwargs)
[all …]
/llvm-project-15.0.7/lldb/third_party/Python/module/unittest2/unittest2/
H A Drunner.py22 def __init__(self, stream): argument
23 self.stream = stream
46 self.stream = stream
53 self.stream.writeln(
55 self.stream.writeln("")
56 self.stream.flush()
70 self.stream.flush()
81 self.stream.flush()
115 self.stream.writeln()
142 self.stream = _WritelnDecorator(stream)
[all …]
/llvm-project-15.0.7/libcxx/test/std/input.output/file.streams/fstreams/fstream.members/
H A Dopen_path.pass.cpp31 std::fstream stream; in main() local
33 stream.open(p, in main()
35 assert(stream.is_open()); in main()
37 stream << 3.25; in main()
38 stream.seekg(0); in main()
39 stream >> x; in main()
46 std::wfstream stream; in main() local
48 stream.open(p, in main()
52 stream << 3.25; in main()
53 stream.seekg(0); in main()
[all …]
/llvm-project-15.0.7/libc/test/src/time/
H A DTmMatcher.h42 stream << label; in describeValue()
43 stream << " sec: " << value.tm_sec; in describeValue()
44 stream << " min: " << value.tm_min; in describeValue()
45 stream << " hour: " << value.tm_hour; in describeValue()
46 stream << " mday: " << value.tm_mday; in describeValue()
47 stream << " mon: " << value.tm_mon; in describeValue()
48 stream << " year: " << value.tm_year; in describeValue()
49 stream << " wday: " << value.tm_wday; in describeValue()
50 stream << " yday: " << value.tm_yday; in describeValue()
51 stream << " isdst: " << value.tm_isdst; in describeValue()
[all …]
/llvm-project-15.0.7/lldb/source/Plugins/Language/CPlusPlus/
H A DCxxStringTypes.cpp60 options.SetStream(&stream); in CharStringSummaryProvider()
64 stream.Printf("Summary Unavailable"); in CharStringSummaryProvider()
70 static bool CharSummaryProvider(ValueObject &valobj, Stream &stream) { in CharSummaryProvider() argument
85 stream.Printf("%s ", value.c_str()); in CharSummaryProvider()
88 options.SetStream(&stream); in CharSummaryProvider()
98 ValueObject &valobj, Stream &stream, const TypeSummaryOptions &) { in Char8StringSummaryProvider() argument
103 ValueObject &valobj, Stream &stream, const TypeSummaryOptions &) { in Char16StringSummaryProvider() argument
134 options.SetStream(&stream); in WCharStringSummaryProvider()
148 stream.Printf("size for wchar_t is not valid"); in WCharStringSummaryProvider()
193 options.SetStream(&stream); in WCharSummaryProvider()
[all …]
H A DLibCxx.cpp87 stream.Printf( in LibcxxFunctionSummaryProvider()
93 stream.Printf( in LibcxxFunctionSummaryProvider()
99 stream.Printf(" Function = %s ", in LibcxxFunctionSummaryProvider()
123 stream.Printf("nullptr"); in LibcxxSmartPointerSummaryProvider()
166 stream.Printf("nullptr"); in LibcxxUniquePointerSummaryProvider()
826 stream.Printf("L\"\""); in LibcxxWStringSummaryProvider()
858 options.SetStream(&stream); in LibcxxWStringSummaryProvider()
907 stream.Printf("\"\""); in LibcxxStringSummaryProvider()
932 options.SetStream(&stream); in LibcxxStringSummaryProvider()
968 stream << "Summary Unavailable"; in formatStringImpl()
[all …]
H A DCxxStringTypes.h19 bool Char8StringSummaryProvider(ValueObject &valobj, Stream &stream,
23 ValueObject &valobj, Stream &stream,
27 ValueObject &valobj, Stream &stream,
30 bool WCharStringSummaryProvider(ValueObject &valobj, Stream &stream,
33 bool Char8SummaryProvider(ValueObject &valobj, Stream &stream,
37 ValueObject &valobj, Stream &stream,
40 bool Char32SummaryProvider(ValueObject &valobj, Stream &stream,
43 bool WCharSummaryProvider(ValueObject &valobj, Stream &stream,
H A DLibCxx.h22 ValueObject &valobj, Stream &stream,
26 ValueObject &valobj, Stream &stream,
30 ValueObject &valobj, Stream &stream,
34 ValueObject &valobj, Stream &stream,
38 ValueObject &valueObj, Stream &stream,
42 ValueObject &valobj, Stream &stream,
46 ValueObject &valobj, Stream &stream,
50 ValueObject &valobj, Stream &stream,
54 ValueObject &valobj, Stream &stream,
58 ValueObject &valobj, Stream &stream,
[all …]
/llvm-project-15.0.7/lldb/source/Plugins/Language/ObjC/
H A DCocoa.h22 bool NSIndexSetSummaryProvider(ValueObject &valobj, Stream &stream,
25 bool NSArraySummaryProvider(ValueObject &valobj, Stream &stream,
29 bool NSDataSummaryProvider(ValueObject &valobj, Stream &stream,
32 bool NSNumberSummaryProvider(ValueObject &valobj, Stream &stream,
41 bool NSTimeZoneSummaryProvider(ValueObject &valobj, Stream &stream,
44 bool NSMachPortSummaryProvider(ValueObject &valobj, Stream &stream,
47 bool NSDateSummaryProvider(ValueObject &valobj, Stream &stream,
50 bool NSBundleSummaryProvider(ValueObject &valobj, Stream &stream,
53 bool NSURLSummaryProvider(ValueObject &valobj, Stream &stream,
75 bool ObjCBOOLSummaryProvider(ValueObject &valobj, Stream &stream,
[all …]
H A DCocoa.cpp226 stream.Printf("mach port: %u", in NSMachPortSummaryProvider()
384 stream.PutCString(prefix.c_str()); in NSNumber_FormatInt128()
388 stream.PutCString(str.c_str()); in NSNumber_FormatInt128()
745 stream.Printf("NaN"); in NSDecimalNumberSummaryProvider()
750 stream.Printf("0"); in NSDecimalNumberSummaryProvider()
760 stream.Printf("-"); in NSDecimalNumberSummaryProvider()
1134 stream.Printf("NO"); in ObjCBOOLSummaryProvider()
1137 stream.Printf("YES"); in ObjCBOOLSummaryProvider()
1140 stream.Printf("%d", value); in ObjCBOOLSummaryProvider()
1163 stream.PutCString("YES"); in ObjCBooleanSummaryProvider()
[all …]
H A DNSString.cpp34 ValueObject &valobj, Stream &stream, in NSStringSummaryProvider() argument
151 options.SetStream(&stream); in NSStringSummaryProvider()
164 options.SetStream(&stream); in NSStringSummaryProvider()
180 options.SetStream(&stream); in NSStringSummaryProvider()
202 options.SetStream(&stream); in NSStringSummaryProvider()
228 options.SetStream(&stream); in NSStringSummaryProvider()
251 options.SetStream(&stream); in NSStringSummaryProvider()
274 options.SetStream(&stream); in NSStringSummaryProvider()
378 stream.Printf("%s", prefix.c_str()); in NSTaggedString_SummaryProvider()
379 stream.Printf("\"%s\"", &bytes[0]); in NSTaggedString_SummaryProvider()
[all …]
H A DCoreMedia.cpp23 ValueObject &valobj, Stream &stream, const TypeSummaryOptions &options) { in CMTimeSummaryProvider() argument
54 stream.Printf("indefinite"); in CMTimeSummaryProvider()
59 stream.Printf("+oo"); in CMTimeSummaryProvider()
64 stream.Printf("-oo"); in CMTimeSummaryProvider()
75 stream.Printf("%" PRId64 " seconds", value); in CMTimeSummaryProvider()
78 stream.Printf("%" PRId64 " half seconds", value); in CMTimeSummaryProvider()
81 stream.Printf("%" PRId64 " third%sof a second", value, in CMTimeSummaryProvider()
85 stream.Printf("%" PRId64 " %" PRId32 "th%sof a second", value, timescale, in CMTimeSummaryProvider()
/llvm-project-15.0.7/libcxx/test/std/input.output/file.streams/fstreams/ofstream.cons/
H A Dpath.pass.cpp40 std::ofstream stream(p); in main() local
41 stream << 3.25; in main()
44 std::ifstream stream(p); in main() local
46 stream >> x; in main()
50 std::ifstream stream(p, std::ios_base::out); in main() local
52 stream >> x; in main()
59 std::wofstream stream(p); in main() local
60 stream << 3.25; in main()
63 std::wifstream stream(p); in main() local
65 stream >> x; in main()
[all …]
/llvm-project-15.0.7/lldb/source/Plugins/SymbolFile/PDB/
H A DPDBLocationToDWARFExpression.cpp88 stream.PutHex8(DW_OP_addr); in ConvertPDBLocationToDWARFExpression()
116 stream.PutHex8(DW_OP_consts); in ConvertPDBLocationToDWARFExpression()
117 stream.PutSLEB128(offset); in ConvertPDBLocationToDWARFExpression()
118 stream.PutHex8(DW_OP_plus); in ConvertPDBLocationToDWARFExpression()
137 stream.PutHex8(DW_OP_bregx); in ConvertPDBLocationToDWARFExpression()
138 stream.PutULEB128(reg_num); in ConvertPDBLocationToDWARFExpression()
143 stream.PutSLEB128(offset); in ConvertPDBLocationToDWARFExpression()
156 stream.PutHex8(DW_OP_regx); in ConvertPDBLocationToDWARFExpression()
157 stream.PutULEB128(reg_num); in ConvertPDBLocationToDWARFExpression()
159 stream.PutHex8(DW_OP_reg0 + reg_num); in ConvertPDBLocationToDWARFExpression()
[all …]
/llvm-project-15.0.7/llvm/tools/llvm-pdbutil/
H A DStreamUtil.cpp51 static inline StreamInfo stream(StreamPurpose Purpose, StringRef Label, in stream() function
118 stream(StreamPurpose::Symbols, "Symbol Records", StreamIdx); in discoverStreamPurposes()
121 stream(StreamPurpose::TpiHash, "TPI Hash", StreamIdx); in discoverStreamPurposes()
124 stream(StreamPurpose::Other, "TPI Aux Hash", StreamIdx); in discoverStreamPurposes()
127 stream(StreamPurpose::IpiHash, "IPI Hash", StreamIdx); in discoverStreamPurposes()
130 stream(StreamPurpose::Other, "IPI Aux Hash", StreamIdx); in discoverStreamPurposes()
134 stream(StreamPurpose::Other, "Exception Data", StreamIdx); in discoverStreamPurposes()
137 stream(StreamPurpose::Other, "Fixup Data", StreamIdx); in discoverStreamPurposes()
143 stream(StreamPurpose::Other, "New FPO Data", StreamIdx); in discoverStreamPurposes()
161 Streams[StreamIdx] = stream(StreamPurpose::Other, in discoverStreamPurposes()
[all …]
/llvm-project-15.0.7/lldb/source/Plugins/SymbolFile/NativePDB/
H A DDWARFLocationExpression.cpp119 if (!writer(stream, register_kind)) in MakeLocationExpressionInternal()
123 std::make_shared<DataBufferHeap>(stream.GetData(), stream.GetSize()); in MakeLocationExpressionInternal()
145 stream.PutHex8(base); in MakeRegisterBasedLocationExpressionInternal()
146 stream.PutULEB128(reg_num); in MakeRegisterBasedLocationExpressionInternal()
151 stream.PutHex8(base + reg_num); in MakeRegisterBasedLocationExpressionInternal()
155 stream.PutSLEB128(*relative_offset); in MakeRegisterBasedLocationExpressionInternal()
189 stream.PutSLEB128(offset); in MakeVFrameRelLocationExpression()
190 stream.PutHex8(llvm::dwarf::DW_OP_plus); in MakeVFrameRelLocationExpression()
205 stream.PutHex8(llvm::dwarf::DW_OP_addr); in MakeGlobalLocationExpression()
215 stream.GetAddressByteSize(), stream.GetByteOrder()); in MakeGlobalLocationExpression()
[all …]
/llvm-project-15.0.7/lldb/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/
H A DRenderScriptScriptGroup.cpp50 Stream &stream = result.GetOutputStream(); in DoExecute() local
107 Stream &stream = result.GetOutputStream(); in DoExecute() local
116 stream.EOL(); in DoExecute()
118 stream.IndentMore(); in DoExecute()
121 stream.Indent(); in DoExecute()
124 stream.EOL(); in DoExecute()
126 stream.IndentMore(); in DoExecute()
128 stream.Indent(); in DoExecute()
130 stream.EOL(); in DoExecute()
132 stream.IndentLess(); in DoExecute()
[all …]
/llvm-project-15.0.7/libcxx/include/
H A Dcstdio48 int fclose(FILE* stream);
49 int fflush(FILE* stream);
70 int fgetc(FILE* stream);
72 int fputc(int c, FILE* stream);
74 int getc(FILE* stream);
77 int putc(int c, FILE* stream);
88 long ftell(FILE* stream);
89 void rewind(FILE* stream);
90 void clearerr(FILE* stream);
91 int feof(FILE* stream);
[all …]
/llvm-project-15.0.7/mlir/lib/ExecutionEngine/
H A DCudaRuntimeWrappers.cpp98 CUstream stream = nullptr; in mgpuStreamCreate() local
100 return stream; in mgpuStreamCreate()
104 CUDA_REPORT_IF_ERROR(cuStreamDestroy(stream)); in mgpuStreamDestroy()
108 mgpuStreamSynchronize(CUstream stream) { in mgpuStreamSynchronize() argument
109 CUDA_REPORT_IF_ERROR(cuStreamSynchronize(stream)); in mgpuStreamSynchronize()
114 CUDA_REPORT_IF_ERROR(cuStreamWaitEvent(stream, event, /*flags=*/0)); in mgpuStreamWaitEvent()
134 CUDA_REPORT_IF_ERROR(cuEventRecord(event, stream));
149 CUstream stream) { in mgpuMemcpy() argument
152 sizeBytes, stream)); in mgpuMemcpy()
156 CUstream stream) { in mgpuMemset32() argument
[all …]
H A DRocmRuntimeWrappers.cpp91 hipStream_t stream = nullptr; in mgpuStreamCreate() local
92 HIP_REPORT_IF_ERROR(hipStreamCreate(&stream)); in mgpuStreamCreate()
93 return stream; in mgpuStreamCreate()
96 extern "C" void mgpuStreamDestroy(hipStream_t stream) { in mgpuStreamDestroy() argument
97 HIP_REPORT_IF_ERROR(hipStreamDestroy(stream)); in mgpuStreamDestroy()
100 extern "C" void mgpuStreamSynchronize(hipStream_t stream) { in mgpuStreamSynchronize() argument
101 return HIP_REPORT_IF_ERROR(hipStreamSynchronize(stream)); in mgpuStreamSynchronize()
124 HIP_REPORT_IF_ERROR(hipEventRecord(event, stream)); in mgpuEventRecord()
139 hipStream_t stream) { in mgpuMemcpy() argument
145 hipStream_t stream) { in mgpuMemset32() argument
[all …]
/llvm-project-15.0.7/lldb/source/Target/
H A DThreadPlanTracer.cpp69 Stream *stream = GetLogStream(); in Log() local
70 if (stream) { in Log()
73 stream->Printf("\n"); in Log()
74 stream->Flush(); in Log()
131 Stream *stream = GetLogStream(); in Log() local
133 if (!stream) in Log()
147 stream->PutCString(" "); in Log()
201 stream->Printf( in Log()
206 stream->PutCString(", "); in Log()
233 stream->EOL(); in Log()
[all …]
/llvm-project-15.0.7/lldb/bindings/
H A Dmacros.swig4 lldb::SBStream stream;
5 $self->GetDescription (stream, Level);
6 const char *desc = stream.GetData();
7 size_t desc_len = stream.GetSize();
19 lldb::SBStream stream;
20 $self->GetDescription (stream);
21 const char *desc = stream.GetData();
22 size_t desc_len = stream.GetSize();

12345678910>>...20